Aider adapter.
Uses aider.conf.yml as the configuration surface and a git post-commit
hook for session signals. Sessions are identified by the commit SHA.
Structs
- Aider
Adapter - Aider integration.
Aider adapter.
Uses aider.conf.yml as the configuration surface and a git post-commit
hook for session signals. Sessions are identified by the commit SHA.